@@ -15,11 +15,11 @@ DBIx::ScopedTransaction - Scope database transactions on DBI handles in code, to
 
 =head1 VERSION
 
-Version 1.0.5
+Version 1.0.6
 
 =cut
 
-our $VERSION = '1.0.5';
+our $VERSION = '1.0.6';
 
 our $DESTROY_LOGGER;
 
@@ -203,10 +203,10 @@ sub commit
 	}
 	else
 	{
-		Carp::cluck(
-			'Failed to commit transaction: ' .
-			( $database_handle->errstr() // '(no error associate with the database handle)' )
-		);
+		my $error = $database_handle->errstr();
+		$error = '(no error associate with the database handle)'
+			if !defined( $error );
+		Carp::cluck( "Failed to commit transaction: $error" );
 		return 0;
 	}
 }
@@ -238,10 +238,10 @@ sub rollback
 	}
 	else
 	{
-		Carp::cluck(
-			'Failed to rollback transaction: ' .
-			( $database_handle->errstr() // '(no error associate with the database handle)' )
-		);
+		my $error = $database_handle->errstr();
+		$error = '(no error associate with the database handle)'
+			if !defined( $error );
+		Carp::cluck( "Failed to rollback transaction: $error" );
 		return 0;
 	}
 }
